@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import re
 
@@ -45,6 +45,10 @@ class ReadOnlyCell(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+
+    def __repr__(self):
+        return "<ReadOnlyCell {0!r}.{1}>".format(self.parent.title, self.coordinate)
+
     @property
     def shared_strings(self):
         return self.parent.shared_strings
@@ -145,4 +149,7 @@ class EmptyCell(object):
     data_type = 'n'
 
 
+    def __repr__(self):
+        return "<EmptyCell>"
+
 EMPTY_CELL = EmptyCell()
