@@ -1,10 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
-
-import pytest
-
-from openpyxl.xml.functions import fromstring, tostring
-from openpyxl.tests.helper import compare_xml
+# Copyright (c) 2010-2018 openpyxl
 
 
 def test_color_descriptor():
