@@ -1,8 +1,8 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
+from collections import OrderedDict
 from openpyxl.compat import safe_string
-from openpyxl.compat import OrderedDict
 
 from openpyxl.descriptors import (
     Typed,
@@ -46,6 +46,8 @@ class NamedStyle(Serialisable):
     hidden = Bool(allow_none=True)
     xfId = Integer(allow_none=True)
     name = String()
+    _wb = None
+    _style = StyleArray()
 
 
     def __init__(self,
@@ -138,6 +140,10 @@ class NamedStyle(Serialisable):
         xf.xfId = None
         xf.pivotButton = None
         xf.quotePrefix = None
+        if self.alignment != Alignment():
+            xf.alignment = self.alignment
+        if self.protection != Protection():
+            xf.protection = self.protection
         return xf
 
 
@@ -267,7 +273,7 @@ class _NamedCellStyleList(Serialisable):
         def sort_fn(v):
             return v.xfId
 
-        styles = NamedStyleList()
+        styles = []
         names = set()
 
         for ns in sorted(self.cellStyle, key=sort_fn):
@@ -280,6 +286,7 @@ class _NamedCellStyleList(Serialisable):
                 builtinId = ns.builtinId
             )
             names.add(ns.name)
-            styles.append(style) # assign xfId
+            style._set_index(len(styles)) # assign xfId
+            styles.append(style)
 
-        return styles
+        return NamedStyleList(styles)
